==> BorderStyles-Standard-0.006.tar.gz: BorderStyles-Standard-0.006/lib/BorderStyle/UTF8/SingleLineDoubleAfterHeader.pm <==
package BorderStyle::UTF8::SingleLineDoubleAfterHeader;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-02-19'; # DATE
our $DIST = 'BorderStyles-Standard'; # DIST
our $VERSION = '0.006'; # VERSION

use strict;
use parent 'BorderStyleBase';
use utf8;

our %BORDER = (
    v => 2,
    summary => 'Just like UTF8::SingleLine but uses double line to separate header row and first data row',
    chars => [
        ['┌','─','┬','┐'], # 0
        ['│','│','│'],     # 1
        ['╞','═','╪','╡', '╤','╧'], # 2
        ['│','│','│'],     # 3
        ['├','─','┼','┤', '┬','┴','├','┤'], # 4
        ['└','─','┴','┘'], # 5
    ],
    utf8 => 1,
);

1;
# ABSTRACT: Just like UTF8::SingleLine but uses double line to separate header row and first data row

__END__

=pod

=encoding UTF-8

=head1 NAME

BorderStyle::UTF8::SingleLineDoubleAfterHeader - Just like UTF8::SingleLine but uses double line to separate header row and first data row

=head1 VERSION

This document describes version 0.006 of BorderStyle::UTF8::SingleLineDoubleAfterHeader (from Perl distribution BorderStyles-Standard), released on 2021-02-19.

=head1 SYNOPSIS

To use with L<Text::ANSITable>:

 use Text::ANSITable;
 my $rows =
   [
     ["ColumName1", "ColumnNameB", "ColumnNameC"],
     ["row1A", "row1B", "row1C"],
     ["row2A", "row2B", "row2C"],
     ["row3A", "row3B", "row3C"],
   ];
 my $t = Text::ANSITable->new;
 $t->border_style("UTF8::SingleLineDoubleAfterHeader");
 $t->columns($rows->[0]);
 $t->add_row($rows->[$_]) for 1 .. $#{ $rows };
 print $t->draw;


Sample output:

 ┌────────────┬─────────────┬─────────────┐
 │ ColumName1 │ ColumnNameB │ ColumnNameC │
 ╞════════════╪═════════════╪═════════════╡
 │ row1A      │ row1B       │ row1C       │
 │ row2A      │ row2B       │ row2C       │
 │ row3A      │ row3B       │ row3C       │
 └────────────┴─────────────┴─────────────┘

To use with L<Text::Table::Span>:

 use Text::Table::Span qw/generate_table/;
 my $rows =
   [
     ["ColumName1", "ColumnNameB", "ColumnNameC"],
     ["row1A", "row1B", "row1C"],
     ["row2A", "row2B", "row2C"],
     ["row3A", "row3B", "row3C"],
   ];
 generate_table(rows=>$rows, header_row=>1, separate_rows=>1, border_style=>"UTF8::SingleLineDoubleAfterHeader");


Sample output:

 ┌────────────┬─────────────┬─────────────┐
 │ ColumName1 │ ColumnNameB │ ColumnNameC │
 ╞════════════╪═════════════╪═════════════╡
 │ row1A      │ row1B       │ row1C       │
 ├────────────┼─────────────┼─────────────┤
 │ row2A      │ row2B       │ row2C       │
 ├────────────┼─────────────┼─────────────┤
 │ row3A      │ row3B       │ row3C       │
 └────────────┴─────────────┴─────────────┘
 

To use with L<Text::Table::TinyBorderStyle>:

 use Text::Table::TinyBorderStyle qw/generate_table/;
 my $rows =
   [
     ["ColumName1", "ColumnNameB", "ColumnNameC"],
     ["row1A", "row1B", "row1C"],
     ["row2A", "row2B", "row2C"],
     ["row3A", "row3B", "row3C"],
   ];
 generate_table(rows=>$rows, header_row=>1, separate_rows=>1, border_style=>"BorderStyle::UTF8::SingleLineDoubleAfterHeader");


Sample output:

 ┌────────────┬─────────────┬─────────────┐
 │ ColumName1 │ ColumnNameB │ ColumnNameC │
 ╞════════════╪═════════════╪═════════════╡
 │ row1A      │ row1B       │ row1C       │
 ├────────────┼─────────────┼─────────────┤
 │ row2A      │ row2B       │ row2C       │
 ├────────────┼─────────────┼─────────────┤
 │ row3A      │ row3B       │ row3C       │
 └────────────┴─────────────┴─────────────┘

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/BorderStyles-Standard>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-BorderStyles-Standard>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-BorderStyles-Standard/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<BorderStyle::Custom>

L<BorderStyle::ASCII::SingleLineDoubleAfterHeader>

L<BorderStyle::UTF8::SingleLine>

L<BorderStyle::UTF8::DoubleLine>

L<BorderStyle::ASCII::SingleLine>

L<BorderStyle::BoxChar::SingleLine>

L<BorderStyle::Custom>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2020 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> BorderStyles-Standard-0.007.tar.gz: BorderStyles-Standard-0.007/lib/BorderStyle/UTF8/SingleLineDoubleAfterHeader.pm <==
package BorderStyle::UTF8::SingleLineDoubleAfterHeader;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-05-12'; # DATE
our $DIST = 'BorderStyles-Standard'; # DIST
our $VERSION = '0.007'; # VERSION

use strict;
use parent 'BorderStyleBase';
use utf8;

our %BORDER = (
    v => 2,
    summary => 'Just like UTF8::SingleLine but uses double line to separate header row and first data row',
    chars => [
        ['┌','─','┬','┐'], # 0
        ['│','│','│'],     # 1
        ['╞','═','╪','╡', '╤','╧'], # 2
        ['│','│','│'],     # 3
        ['├','─','┼','┤', '┬','┴','├','┤'], # 4
        ['└','─','┴','┘'], # 5
    ],
    utf8 => 1,
);

1;
# ABSTRACT: Just like UTF8::SingleLine but uses double line to separate header row and first data row

__END__

=pod

=encoding UTF-8

=head1 NAME

BorderStyle::UTF8::SingleLineDoubleAfterHeader - Just like UTF8::SingleLine but uses double line to separate header row and first data row

=head1 VERSION

This document describes version 0.007 of BorderStyle::UTF8::SingleLineDoubleAfterHeader (from Perl distribution BorderStyles-Standard), released on 2021-05-12.

=head1 SYNOPSIS

To use with L<Text::ANSITable>:

 use Text::ANSITable;
 my $rows =
   [
     ["ColumName1", "ColumnNameB", "ColumnNameC"],
     ["row1A", "row1B", "row1C"],
     ["row2A", "row2B", "row2C"],
     ["row3A", "row3B", "row3C"],
   ];
 my $t = Text::ANSITable->new;
 $t->border_style("UTF8::SingleLineDoubleAfterHeader");
 $t->columns($rows->[0]);
 $t->add_row($rows->[$_]) for 1 .. $#{ $rows };
 print $t->draw;


Sample output:

 ┌────────────┬─────────────┬─────────────┐
 │ ColumName1 │ ColumnNameB │ ColumnNameC │
 ╞════════════╪═════════════╪═════════════╡
 │ row1A      │ row1B       │ row1C       │
 │ row2A      │ row2B       │ row2C       │
 │ row3A      │ row3B       │ row3C       │
 └────────────┴─────────────┴─────────────┘

To use with L<Text::Table::More>:

 use Text::Table::More qw/generate_table/;
 my $rows =
   [
     ["ColumName1", "ColumnNameB", "ColumnNameC"],
     ["row1A", "row1B", "row1C"],
     ["row2A", "row2B", "row2C"],
     ["row3A", "row3B", "row3C"],
   ];
 generate_table(rows=>$rows, header_row=>1, separate_rows=>1, border_style=>"UTF8::SingleLineDoubleAfterHeader");


Sample output:

 ┌────────────┬─────────────┬─────────────┐
 │ ColumName1 │ ColumnNameB │ ColumnNameC │
 ╞════════════╪═════════════╪═════════════╡
 │ row1A      │ row1B       │ row1C       │
 ├────────────┼─────────────┼─────────────┤
 │ row2A      │ row2B       │ row2C       │
 ├────────────┼─────────────┼─────────────┤
 │ row3A      │ row3B       │ row3C       │
 └────────────┴─────────────┴─────────────┘
 

To use with L<Text::Table::TinyBorderStyle>:

 use Text::Table::TinyBorderStyle qw/generate_table/;
 my $rows =
   [
     ["ColumName1", "ColumnNameB", "ColumnNameC"],
     ["row1A", "row1B", "row1C"],
     ["row2A", "row2B", "row2C"],
     ["row3A", "row3B", "row3C"],
   ];
 generate_table(rows=>$rows, header_row=>1, separate_rows=>1, border_style=>"BorderStyle::UTF8::SingleLineDoubleAfterHeader");


Sample output:

 ┌────────────┬─────────────┬─────────────┐
 │ ColumName1 │ ColumnNameB │ ColumnNameC │
 ╞════════════╪═════════════╪═════════════╡
 │ row1A      │ row1B       │ row1C       │
 ├────────────┼─────────────┼─────────────┤
 │ row2A      │ row2B       │ row2C       │
 ├────────────┼─────────────┼─────────────┤
 │ row3A      │ row3B       │ row3C       │
 └────────────┴─────────────┴─────────────┘

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/BorderStyles-Standard>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-BorderStyles-Standard>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=BorderStyles-Standard>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<BorderStyle::Custom>

L<BorderStyle::ASCII::SingleLineDoubleAfterHeader>

L<BorderStyle::UTF8::SingleLine>

L<BorderStyle::UTF8::DoubleLine>

L<BorderStyle::ASCII::SingleLine>

L<BorderStyle::BoxChar::SingleLine>

L<BorderStyle::Custom>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2020 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
